@@ -18,7 +18,6 @@ create.model <- function(model, formula, data,  name = NULL){
   return(model)
 }
 
-
 #' train.qda
 #'
 #' @description Provides a wrapping function for the \code{\link[MASS]{qda}}.
@@ -113,6 +112,8 @@ train.lda <- function(formula, data, ..., subset, na.action){
 #' @param subset an optional vector specifying a subset of observations to be used in the fitting process.
 #' @param na.action a function that indicates how to process ‘NA’ values. Default=na.rpart.
 #'
+#' @importFrom ada ada
+#'
 #' @seealso The internal function is from package \code{\link[ada]{ada}}.
 #'
 #' @return A object ada.prmdt with additional information to the model that allows to homogenize the results.
@@ -231,6 +232,8 @@ train.adabag <- function(formula, data, boos = TRUE, mfinal = 100, coeflearn = '
 #' @param cost a vector of non-negative costs, one for each variable in the model. Defaults to one for all variables. These are scalings to be applied when considering splits, so the improvement on splitting on a variable is divided by its cost in deciding which split to choose.
 #' @param ... arguments to \code{\link[rpart]{rpart.control}} may also be specified in the call to rpart. They are checked against the list of valid arguments.
 #'
+#' @importFrom rpart rpart na.rpart
+#'
 #' @seealso The internal function is from package \code{\link[rpart]{rpart}}.
 #'
 #' @return A object rpart.prmdt with additional information to the model that allows to homogenize the results.
@@ -283,6 +286,8 @@ train.rpart <- function(formula, data, weights, subset, na.action = na.rpart, me
 #' @param subset For data given in a data frame, an index vector specifying the cases to be used in the training sample. (NOTE: If given, this argument must be named.)
 #' @param na.action A function to specify the action to be taken if NAs are found. The default action is not to count them for the computation of the probability factors. An alternative is na.omit, which leads to rejection of cases with missing values on any required variable. (NOTE: If given, this argument must be named.)
 #'
+#' @importFrom e1071 naiveBayes
+#'
 #' @seealso The internal function is from package \code{\link[e1071]{naiveBayes}}.
 #'
 #' @return A object bayes.prmdt with additional information to the model that allows to homogenize the results.
@@ -333,6 +338,9 @@ train.bayes <- function(formula, data, laplace = 0, ..., subset, na.action = na.
 #' @param subset an index vector indicating which rows should be used. (NOTE: If given, this argument must be named.)
 #' @param na.action A function to specify the action to be taken if NAs are found. (NOTE: If given, this argument must be named.)
 #'
+#' @importFrom randomForest randomForest
+#' @importFrom stats na.fail
+#'
 #' @seealso The internal function is from package \code{\link[randomForest]{randomForest}}.
 #'
 #' @return A object randomForest.prmdt with additional information to the model that allows to homogenize the results.
@@ -392,6 +400,8 @@ train.randomForest <- function(formula, data, ..., subset, na.action = na.fail){
 #' @param contrasts A vector containing the 'unordered' and 'ordered' contrasts to use.
 #' @param ... Further arguments passed to or from other methods.
 #'
+#' @importFrom kknn train.kknn contr.dummy contr.ordinal
+#'
 #' @seealso The internal function is from package \code{\link[kknn]{train.kknn}}.
 #'
 #' @return A object knn.prmdt with additional information to the model that allows to homogenize the results.
@@ -448,6 +458,8 @@ train.knn <- function(formula, data, kmax = 11, ks = NULL, distance = 2, kernel
 #'                  values on any required variable. (NOTE: If given, this argument must be named.)
 #' @param contrasts a list of contrasts to be used for some or all of the factors appearing as variables in the model formula.
 #'
+#' @importFrom nnet nnet
+#'
 #' @seealso The internal function is from package \code{\link[nnet]{nnet}}.
 #'
 #' @return A object nnet.prmdt with additional information to the model that allows to homogenize the results.
@@ -521,6 +533,11 @@ train.nnet <- function(formula, data, weights, ..., subset, na.action, contrasts
 #' @param likelihood logical. If the error function is equal to the negative log-likelihood function, the
 #'                   information criteria AIC and BIC will be calculated. Furthermore the usage of confidence.interval is meaningfull.
 #'
+#' @importFrom neuralnet neuralnet
+#' @importFrom dummies dummy.data.frame
+#' @importFrom stats update as.formula
+#' @importFrom utils head
+#'
 #' @seealso The internal function is from package \code{\link[neuralnet]{neuralnet}}.
 #'
 #' @return A object neuralnet.prmdt with additional information to the model that allows to homogenize the results.
@@ -529,25 +546,6 @@ train.nnet <- function(formula, data, weights, ..., subset, na.action, contrasts
 #'
 #' @export
 #'
-#' @examples
-#'
-#' \dontrun{
-#' data("iris")
-#' n <- seq_len(nrow(iris))
-#' .sample <- sample(n, length(n) * 0.75)
-#' data.train <- iris[.sample,]
-#' data.test <- iris[-.sample,]
-#'
-#' modelo.neuralnet <- train.neuralnet(Species~., data.train,hidden = c(10, 14, 13),
-#'                                     linear.output = FALSE, threshold = 0.01, stepmax = 1e+06)
-#' modelo.neuralnet
-#' prob <- predict(modelo.neuralnet, data.test, type = "prob")
-#' prob
-#' prediccion <- predict(modelo.neuralnet, data.test, type = "class")
-#' prediccion
-#' confusion.matrix(data.test, prediccion)
-#' }
-#'
 train.neuralnet <- function(formula, data, hidden = 1, threshold = 0.01, stepmax = 1e+05, rep = 1, startweights = NULL, learningrate.limit = NULL,
                             learningrate.factor = list(minus = 0.5, plus = 1.2), learningrate = NULL, lifesign = "none", lifesign.step = 1000,
                             algorithm = "rprop+", err.fct = "sse", act.fct = "logistic", linear.output = TRUE, exclude = NULL, constant.weights = NULL,
@@ -611,6 +609,8 @@ train.neuralnet <- function(formula, data, hidden = 1, threshold = 0.01, stepmax
 #'              recycled as many times as needed. Per default, data are scaled internally (both x and y variables) to zero mean and unit variance.
 #'              The center and scale values are returned and used for later predictions.
 #'
+#' @importFrom e1071 svm
+#'
 #' @seealso The internal function is from package \code{\link[e1071]{svm}}.
 #'
 #' @return A object svm.prmdt with additional information to the model that allows to homogenize the results.
@@ -710,6 +710,9 @@ train.svm <- function(formula, data, ..., subset, na.action = na.omit, scale = T
 #' @param colsample_bytree colsample_bytree subsample ratio of columns when constructing each tree. Default: 1
 #' @param ... other parameters to pass to params.
 #'
+#' @importFrom xgboost xgboost xgb.DMatrix xgb.train
+#' @import dplyr
+#'
 #' @seealso The internal function is from package \code{\link[xgboost]{xgb.train}}.
 #'
 #' @return A object xgb.Booster.prmdt with additional information to the model that allows to homogenize the results.
@@ -751,7 +754,7 @@ train.xgboost <- function(formula, data, nrounds, watchlist = list(), obj = NULL
     .colnames <- colnames(data[,-selector, drop = FALSE])
   }
 
-  train_aux <- data %>% select(c(.colnames,var.predict)) %>% select_on_class(c("numeric","integer", "factor"))
+  train_aux <- data |> select(c(.colnames,var.predict)) |> select_on_class(c("numeric","integer", "factor"))
 
   train_aux[] <- lapply(train_aux, as.numeric)
 
@@ -794,8 +797,6 @@ train.xgboost <- function(formula, data, nrounds, watchlist = list(), obj = NULL
 
 }
 
-
-
 #' train.glm
 #'
 #' @description Provides a wrapping function for the \code{\link[stats]{glm}}
@@ -821,6 +822,8 @@ train.xgboost <- function(formula, data, nrounds, watchlist = list(), obj = NULL
 #' @param ... For glm: arguments to be used to form the default control argument if it is not supplied directly.
 #'            For weights: further arguments passed to or from other methods.
 #'
+#' @importFrom stats glm binomial
+#'
 #' @seealso The internal function is from package \code{\link[stats]{glm}}.
 #'
 #' @seealso The internal function is from package \code{\link[stats]{glm}}.
@@ -887,6 +890,8 @@ train.glm <- function(formula,  data, family = binomial, weights, subset, na.act
 #'
 #' @note The parameter information was taken from the original function \code{\link[glmnet]{glmnet}}.
 #'
+#' @importFrom stats model.matrix
+#'
 #' @export
 #'
 #' @examples
